@@ -1,7 +1,7 @@
 import math
 
 from PIL import ImageDraw, ImageFont 
-font = ImageFont.truetype("FreeMonoBold.ttf", 100)
+font = ImageFont.truetype(font="FreeMono.ttf", size=100)
 
 
 class Layer:
